summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--vtysh/vtysh.c6
-rw-r--r--vtysh/vtysh_main.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/vtysh/vtysh_main.c b/vtysh/vtysh_main.c
index 76956574c..a4f27b61c 100644
--- a/vtysh/vtysh_main.c
+++ b/vtysh/vtysh_main.c
@@ -587,7 +587,7 @@ int main(int argc, char **argv, char **env)
* Setup history file for use by both -c and regular input
* If we can't find the home directory, then don't store
* the history information.
- * VTYSH_HISTFILE is prefered over command line
+ * VTYSH_HISTFILE is preferred over command line
* argument (-H/--histfile).
*/
if (getenv("VTYSH_HISTFILE")) {
diff --git a/vtysh/vtysh.c b/vtysh/vtysh.c
index 8e95aaa47..336fe8b30 100644
--- a/vtysh/vtysh.c
+++ b/vtysh/vtysh.c
@@ -818,7 +818,7 @@ int vtysh_mark_file(const char *filename)
return 0;
}
/* Configration make from file. */
int vtysh_config_from_file(struct vty *vty, FILE *fp)
{
int ret;
@@ -1586,7 +1586,7 @@ DEFUNSH(VTYSH_REALLYALL, vtysh_end_all, vtysh_end_all_cmd, "end",
DEFUNSH(VTYSH_ZEBRA, srv6, srv6_cmd,
"srv6",
- "Segment-Routing SRv6 configration\n")
+ "Segment-Routing SRv6 configuration\n")
{
vty->node = SRV6_NODE;
return CMD_SUCCESS;
@@ -1594,7 +1594,7 @@ DEFUNSH(VTYSH_ZEBRA, srv6, srv6_cmd,
DEFUNSH(VTYSH_ZEBRA, srv6_locators, srv6_locators_cmd,
"locators",
- "Segment-Routing SRv6 locators configration\n")
+ "Segment-Routing SRv6 locators configuration\n")
{
vty->node = SRV6_LOCS_NODE;
return CMD_SUCCESS;
@@ -818,7 +818,7 @@ int vtysh_mark_file(const char *filename)
return 0;
}
-/* Configration make from file. */
+/* Configuration make from file. */
int vtysh_config_from_file(struct vty *vty, FILE *fp)
{